@@ -2,6 +2,7 @@ from os import path
 from os import listdir
 import logging
 from dataclasses import dataclass
+import errno
 
 from ansidocs.classes.abstract_project_part import AbstractProjectPart
 from ansidocs.classes.abstract_project_part import AbstractDirContent
@@ -23,7 +24,11 @@ class Playbooks(AbstractProjectPart):
         super().__init__(layout=layout, project_root=project_root)
         self.root_dir = path.abspath(path.join(self.project_root, layout.part_paths['playbooks']))
         if not path.exists(self.root_dir):
-            raise FileNotFoundError(f"Unable to find playbooks project part directory {self.root_dir}")
+            raise FileNotFoundError(
+                errno.ENOENT,
+                f"Unable to find defaults project part directory {self.root_dir}",
+                self.root_dir)
+
 
     def get_content(self, search_path: str = None):
         playbooks = []
