@@ -4,11 +4,16 @@ from os import path
 import logging
 
 
+logger = logging.getLogger(__name__)
+
+
 def parseArgs():
     parser = argparse.ArgumentParser()
-    parser.add_argument("-l", "--loglevel", dest="loglevel", default='WARNING',
-                        help="Log level for python logging, defaults " +
-                        "to WARNING. Set to WARNING, INFO, DEBUG, ERROR")
+    parser.add_argument('--verbose', '-v', dest="verbose", action='count', default=0,
+                        help="Increase program verbosity, use multiple 'v' for more logging")
+    parser.add_argument('--quiet', '-q', dest="quiet", action='store_true',
+                        help="Only display errors")
+
     parser.add_argument("-c", "--config-dir", dest="config_dir",
                         help="Path to the config dir",
                         default=path.join(path.expanduser('~'), '.ansidocs'))
@@ -19,6 +24,10 @@ def parseArgs():
     gen_parser = subparsers.add_parser("generate", aliases=["gen"], help="Generate or update an existing readme")
     gen_parser.add_argument("-d", "--directory", dest="directory", default=".",
                             help="Directory where readme should be generated")
+    gen_parser.add_argument("-l", "--layout", dest="force_layout", required=False,
+                            help="Force a layout for the project specified. Default is to let the program auto " +
+                            "determine the layout")
+
     test_parser = subparsers.add_parser("test", help="Test if the existing readme matches the expected readme")
 
     conf_parser = subparsers.add_parser("config", help="Create or refresh your config directory")
@@ -33,22 +42,38 @@ def parseArgs():
     return parser.parse_args()
 
 
+def determine_log_level(verbose: int, starting_level: str = "WARNING"):
+    # https://docs.python.org/3/library/logging.html#levels
+    verbose_level_int = verbose * 10
+    calculated_level = logging.getLevelName(starting_level) - verbose_level_int
+    if calculated_level < 10:
+        calculated_level = 10   # this is the minimum we support, debug
+    return logging.getLevelName(calculated_level)
+
+
 def main():
     args = parseArgs()
-    logging.basicConfig(level=args.loglevel)
+    if args.quiet:
+        # override any other logging configs
+        logging.basicConfig(level=logging.ERROR)
     args.func(args)
 
 
 def gen(args):
+    logging.basicConfig(level=determine_log_level(args.verbose))
     ansidocs.generate(
         directory=args.directory,
-        config_dir=args.config_dir)
+        config_dir=args.config_dir,
+        force_layout=args.force_layout
+    )
 
 
 def conf(args):
+    logging.basicConfig(level=determine_log_level(args.verbose, starting_level="INFO"))
     ansidocs.init_config_dir(
         config_dir=args.config_dir,
-        refresh_configs=args.refresh_configs)
+        refresh_configs=args.refresh_configs
+    )
 
 
 def test():
